summaryrefslogtreecommitdiffstats
path: root/ksim/monitors/lm_sensors
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit625904bd3097f9749450428904ca14ff2531824d (patch)
treea45c43d5de71cb720078fa1272a4339815a919be /ksim/monitors/lm_sensors
parent6335dc55802871b5a43492f217b6edbb420204c4 (diff)
downloadtdeutils-625904bd3097f9749450428904ca14ff2531824d.tar.gz
tdeutils-625904bd3097f9749450428904ca14ff2531824d.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeutils@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ksim/monitors/lm_sensors')
-rw-r--r--ksim/monitors/lm_sensors/NVCtrl.c20
-rw-r--r--ksim/monitors/lm_sensors/NVCtrl.h22
-rw-r--r--ksim/monitors/lm_sensors/NVCtrlLib.h14
-rw-r--r--ksim/monitors/lm_sensors/ksimsensors.cpp4
-rw-r--r--ksim/monitors/lm_sensors/ksimsensors.h2
-rw-r--r--ksim/monitors/lm_sensors/nv_control.h10
-rw-r--r--ksim/monitors/lm_sensors/sensorsconfig.cpp8
-rw-r--r--ksim/monitors/lm_sensors/sensorsconfig.h2
8 files changed, 41 insertions, 41 deletions
diff --git a/ksim/monitors/lm_sensors/NVCtrl.c b/ksim/monitors/lm_sensors/NVCtrl.c
index dd5f500..6c61b8a 100644
--- a/ksim/monitors/lm_sensors/NVCtrl.c
+++ b/ksim/monitors/lm_sensors/NVCtrl.c
@@ -143,7 +143,7 @@ Bool XNVCTRLIsNvScreen (
void XNVCTRLSetAttribute (
Display *dpy,
int screen,
- unsigned int display_tqmask,
+ unsigned int display_mask,
unsigned int attribute,
int value
){
@@ -157,7 +157,7 @@ void XNVCTRLSetAttribute (
req->reqType = info->codes->major_opcode;
req->nvReqType = X_nvCtrlSetAttribute;
req->screen = screen;
- req->display_tqmask = display_tqmask;
+ req->display_mask = display_mask;
req->attribute = attribute;
req->value = value;
UnlockDisplay (dpy);
@@ -168,7 +168,7 @@ void XNVCTRLSetAttribute (
Bool XNVCTRLQueryAttribute (
Display *dpy,
int screen,
- unsigned int display_tqmask,
+ unsigned int display_mask,
unsigned int attribute,
int *value
){
@@ -187,7 +187,7 @@ Bool XNVCTRLQueryAttribute (
req->reqType = info->codes->major_opcode;
req->nvReqType = X_nvCtrlQueryAttribute;
req->screen = screen;
- req->display_tqmask = display_tqmask;
+ req->display_mask = display_mask;
req->attribute = attribute;
if (!_XReply (dpy, (xReply *) &rep, 0, xTrue)) {
UnlockDisplay (dpy);
@@ -205,7 +205,7 @@ Bool XNVCTRLQueryAttribute (
Bool XNVCTRLQueryStringAttribute (
Display *dpy,
int screen,
- unsigned int display_tqmask,
+ unsigned int display_mask,
unsigned int attribute,
char **ptr
){
@@ -227,7 +227,7 @@ Bool XNVCTRLQueryStringAttribute (
req->reqType = info->codes->major_opcode;
req->nvReqType = X_nvCtrlQueryStringAttribute;
req->screen = screen;
- req->display_tqmask = display_tqmask;
+ req->display_mask = display_mask;
req->attribute = attribute;
if (!_XReply (dpy, (xReply *) &rep, 0, False)) {
UnlockDisplay (dpy);
@@ -256,7 +256,7 @@ Bool XNVCTRLQueryStringAttribute (
Bool XNVCTRLQueryValidAttributeValues (
Display *dpy,
int screen,
- unsigned int display_tqmask,
+ unsigned int display_mask,
unsigned int attribute,
NVCTRLAttributeValidValuesRec *values
){
@@ -277,7 +277,7 @@ Bool XNVCTRLQueryValidAttributeValues (
req->reqType = info->codes->major_opcode;
req->nvReqType = X_nvCtrlQueryValidAttributeValues;
req->screen = screen;
- req->display_tqmask = display_tqmask;
+ req->display_mask = display_mask;
req->attribute = attribute;
if (!_XReply (dpy, (xReply *) &rep, 0, xTrue)) {
UnlockDisplay (dpy);
@@ -343,8 +343,8 @@ static Bool wire_to_event (Display *dpy, XEvent *host, xEvent *wire)
re->attribute_changed.display = dpy;
re->attribute_changed.time = event->u.attribute_changed.time;
re->attribute_changed.screen = event->u.attribute_changed.screen;
- re->attribute_changed.display_tqmask =
- event->u.attribute_changed.display_tqmask;
+ re->attribute_changed.display_mask =
+ event->u.attribute_changed.display_mask;
re->attribute_changed.attribute = event->u.attribute_changed.attribute;
re->attribute_changed.value = event->u.attribute_changed.value;
break;
diff --git a/ksim/monitors/lm_sensors/NVCtrl.h b/ksim/monitors/lm_sensors/NVCtrl.h
index 5e78e27..81c9432 100644
--- a/ksim/monitors/lm_sensors/NVCtrl.h
+++ b/ksim/monitors/lm_sensors/NVCtrl.h
@@ -26,7 +26,7 @@
/*
* Integer attributes; these are settable/gettable via
* XNVCTRLSetAttribute() and XNVCTRLQueryAttribute, respectively.
- * Some attributes may only be read; some may require a display_tqmask
+ * Some attributes may only be read; some may require a display_mask
* argument. This information is encoded in the "permission" comment
* after each attribute #define, and can be queried at run time with
* XNVCTRLQueryValidAttributeValues().
@@ -40,14 +40,14 @@
* various reasons: they represent static system information, they
* can only be changed by changing an XF86Config option, etc).
*
- * D: The attribute requires the display tqmask argument. The
+ * D: The attribute requires the display mask argument. The
* attributes NV_CTRL_CONNECTED_DISPLAYS and NV_CTRL_ENABLED_DISPLAYS
- * will be a bittqmask of what display devices are connected and what
+ * will be a bitmask of what display devices are connected and what
* display devices are enabled for use in X, respectively. Each bit
- * in the bittqmask represents a display device; it is these bits which
- * should be used as the display_tqmask when dealing with attributes
+ * in the bitmask represents a display device; it is these bits which
+ * should be used as the display_mask when dealing with attributes
* designated with "D" below. For attributes that do not require the
- * display tqmask, the argument is ignored.
+ * display mask, the argument is ignored.
*/
@@ -249,7 +249,7 @@
/*
- * NV_CTRL_CONNECTED_DISPLAYS - returns a display tqmask indicating what
+ * NV_CTRL_CONNECTED_DISPLAYS - returns a display mask indicating what
* display devices are connected to the GPU driving the specified X
* screen.
*/
@@ -258,7 +258,7 @@
/*
- * NV_CTRL_ENABLED_DISPLAYS - returns a display tqmask indicating what
+ * NV_CTRL_ENABLED_DISPLAYS - returns a display mask indicating what
* display devices are enabled for use on the specified X screen.
*/
@@ -717,7 +717,7 @@
/*
* NV_CTRL_STRING_DISPLAY_DEVICE_NAME - name of the display device
- * specified in the display_tqmask argument.
+ * specified in the display_mask argument.
*/
#define NV_CTRL_STRING_DISPLAY_DEVICE_NAME 4 /* R-D */
@@ -746,7 +746,7 @@
* is no fixed range of valid values.
*
* ATTRIBUTE_TYPE_BITMASK : the attribute is an integer value,
- * interpretted as a bittqmask.
+ * interpretted as a bitmask.
*
* ATTRIBUTE_TYPE_BOOL : the attribute is a boolean, valid values are
* either 1 (on/true) or 0 (off/false).
@@ -763,7 +763,7 @@
* which can only have certain values, depending on GPU.
*
*
- * The permissions field of NVCTRLAttributeValidValuesRec is a bittqmask
+ * The permissions field of NVCTRLAttributeValidValuesRec is a bitmask
* that may contain:
*
* ATTRIBUTE_TYPE_READ
diff --git a/ksim/monitors/lm_sensors/ksimsensors.cpp b/ksim/monitors/lm_sensors/ksimsensors.cpp
index 76bc4c3..eb2614f 100644
--- a/ksim/monitors/lm_sensors/ksimsensors.cpp
+++ b/ksim/monitors/lm_sensors/ksimsensors.cpp
@@ -71,8 +71,8 @@ void PluginModule::showAbout()
KAboutApplication(&aboutData).exec();
}
-SensorsView::SensorsView(KSim::PluginObject *tqparent, const char *name)
- : DCOPObject("sensors"), KSim::PluginView(tqparent, name)
+SensorsView::SensorsView(KSim::PluginObject *parent, const char *name)
+ : DCOPObject("sensors"), KSim::PluginView(parent, name)
{
config()->setGroup("Sensors");
(new TQVBoxLayout(this))->setAutoAdd(true);
diff --git a/ksim/monitors/lm_sensors/ksimsensors.h b/ksim/monitors/lm_sensors/ksimsensors.h
index 195899e..97fa757 100644
--- a/ksim/monitors/lm_sensors/ksimsensors.h
+++ b/ksim/monitors/lm_sensors/ksimsensors.h
@@ -50,7 +50,7 @@ class SensorsView : public KSim::PluginView, public KSimSensorsIface
Q_OBJECT
TQ_OBJECT
public:
- SensorsView(KSim::PluginObject *tqparent, const char *name);
+ SensorsView(KSim::PluginObject *parent, const char *name);
~SensorsView();
virtual void reparseConfig();
diff --git a/ksim/monitors/lm_sensors/nv_control.h b/ksim/monitors/lm_sensors/nv_control.h
index 9900a00..d94ee95 100644
--- a/ksim/monitors/lm_sensors/nv_control.h
+++ b/ksim/monitors/lm_sensors/nv_control.h
@@ -87,7 +87,7 @@ typedef struct {
CARD8 nvReqType;
CARD16 length B16;
CARD32 screen B32;
- CARD32 display_tqmask B32;
+ CARD32 display_mask B32;
CARD32 attribute B32;
} xnvCtrlQueryAttributeReq;
#define sz_xnvCtrlQueryAttributeReq 16
@@ -111,7 +111,7 @@ typedef struct {
CARD8 nvReqType;
CARD16 length B16;
CARD32 screen B32;
- CARD32 display_tqmask B32;
+ CARD32 display_mask B32;
CARD32 attribute B32;
INT32 value B32;
} xnvCtrlSetAttributeReq;
@@ -122,7 +122,7 @@ typedef struct {
CARD8 nvReqType;
CARD16 length B16;
CARD32 screen B32;
- CARD32 display_tqmask B32;
+ CARD32 display_mask B32;
CARD32 attribute B32;
} xnvCtrlQueryStringAttributeReq;
#define sz_xnvCtrlQueryStringAttributeReq 16
@@ -150,7 +150,7 @@ typedef struct {
CARD8 nvReqType;
CARD16 length B16;
CARD32 screen B32;
- CARD32 display_tqmask B32;
+ CARD32 display_mask B32;
CARD32 attribute B32;
} xnvCtrlQueryValidAttributeValuesReq;
#define sz_xnvCtrlQueryValidAttributeValuesReq 16
@@ -192,7 +192,7 @@ typedef struct {
CARD16 sequenceNumber B16;
Time time B32;
CARD32 screen B32;
- CARD32 display_tqmask B32;
+ CARD32 display_mask B32;
CARD32 attribute B32;
CARD32 value B32;
CARD32 pad0 B32;
diff --git a/ksim/monitors/lm_sensors/sensorsconfig.cpp b/ksim/monitors/lm_sensors/sensorsconfig.cpp
index 8b1ff46..1f1cf10 100644
--- a/ksim/monitors/lm_sensors/sensorsconfig.cpp
+++ b/ksim/monitors/lm_sensors/sensorsconfig.cpp
@@ -40,10 +40,10 @@
class SensorViewItem : public TQCheckListItem
{
public:
- SensorViewItem(TQListView *tqparent, const TQString &text1,
+ SensorViewItem(TQListView *parent, const TQString &text1,
const TQString &text2, const TQString &text3,
const TQString &text4)
- : TQCheckListItem(tqparent, text1, CheckBox)
+ : TQCheckListItem(parent, text1, CheckBox)
{
setText(1, text2);
setText(2, text3);
@@ -51,8 +51,8 @@ class SensorViewItem : public TQCheckListItem
}
};
-SensorsConfig::SensorsConfig(KSim::PluginObject *tqparent, const char *name)
- : KSim::PluginPage(tqparent, name)
+SensorsConfig::SensorsConfig(KSim::PluginObject *parent, const char *name)
+ : KSim::PluginPage(parent, name)
{
m_layout = new TQGridLayout(this);
m_layout->setSpacing(6);
diff --git a/ksim/monitors/lm_sensors/sensorsconfig.h b/ksim/monitors/lm_sensors/sensorsconfig.h
index f37c599..6e27e3d 100644
--- a/ksim/monitors/lm_sensors/sensorsconfig.h
+++ b/ksim/monitors/lm_sensors/sensorsconfig.h
@@ -38,7 +38,7 @@ class SensorsConfig : public KSim::PluginPage
Q_OBJECT
TQ_OBJECT
public:
- SensorsConfig(KSim::PluginObject *tqparent, const char *name);
+ SensorsConfig(KSim::PluginObject *parent, const char *name);
~SensorsConfig();
void saveConfig();
diff --git a/ksim/monitors/lm_sensors/NVCtrlLib.h b/ksim/monitors/lm_sensors/NVCtrlLib.h
index 704071c..8d9cec4 100644
--- a/ksim/monitors/lm_sensors/NVCtrlLib.h
+++ b/ksim/monitors/lm_sensors/NVCtrlLib.h
@@ -55,7 +55,7 @@ Bool XNVCTRLIsNvScreen (
* Sets the attribute to the given value. The attributes and their
* possible values are listed in NVCtrl.h.
*
* Not all attributes require the display_tqmask parameter; see
* NVCtrl.h for details.
*
* Possible errors:
@@ -66,7 +66,7 @@ Bool XNVCTRLIsNvScreen (
void XNVCTRLSetAttribute (
Display *dpy,
int screen,
- unsigned int display_tqmask,
+ unsigned int display_mask,
unsigned int attribute,
int value
);
@@ -78,7 +78,7 @@ void XNVCTRLSetAttribute (
* If XNVCTRLQueryAttribute returns True, value will contain the
* value of the specified attribute.
*
* Not all attributes require the display_tqmask parameter; see
* NVCtrl.h for details.
*
* Possible errors:
@@ -90,7 +90,7 @@ void XNVCTRLSetAttribute (
Bool XNVCTRLQueryAttribute (
Display *dpy,
int screen,
- unsigned int display_tqmask,
+ unsigned int display_mask,
unsigned int attribute,
int *value
);
@@ -112,7 +112,7 @@ Bool XNVCTRLQueryAttribute (
Bool XNVCTRLQueryStringAttribute (
Display *dpy,
int screen,
- unsigned int display_tqmask,
+ unsigned int display_mask,
unsigned int attribute,
char **ptr
);
@@ -129,7 +129,7 @@ Bool XNVCTRLQueryStringAttribute (
Bool XNVCTRLQueryValidAttributeValues (
Display *dpy,
int screen,
- unsigned int display_tqmask,
+ unsigned int display_mask,
unsigned int attribute,
NVCTRLAttributeValidValuesRec *values
);
@@ -166,7 +166,7 @@ typedef struct {
Display *display;
Time time;
int screen;
- unsigned int display_tqmask;
+ unsigned int display_mask;
unsigned int attribute;
int value;
} XNVCtrlAttributeChangedEvent;
@@ -55,7 +55,7 @@ Bool XNVCTRLIsNvScreen (
* possible values are listed in NVCtrl.h.
*
- * Not all attributes require the display_tqmask parameter; see
+ * Not all attributes require the display_mask parameter; see
* NVCtrl.h for details.
*
@@ -78,7 +78,7 @@ void XNVCTRLSetAttribute (
* value of the specified attribute.
*
- * Not all attributes require the display_tqmask parameter; see
+ * Not all attributes require the display_mask parameter; see
* NVCtrl.h for details.
*